=========
Tutorials
=========

.. toctree::

   tutorial_profile_noisy_discrete
   tutorial_profile_noisy_discrete_more_options
   tutorial_tau_vector
   tutorial_ternary_plots
   tutorial_binary_plots
   tutorial_probabilities
   tutorial_iterables
   tutorial_more_classes_of_profiles
   tutorial_asymptotic_developments
